@@ -360,7 +360,7 @@ class GromacsParser(FairdiParser):
     def __init__(self):
         super().__init__(
             name='parsers/gromacs', code_name='Gromacs', code_homepage='http://www.gromacs.org/',
-            domain='dft', mainfile_contents_re=r'gmx mdrun, VERSION')
+            domain='dft', mainfile_contents_re=r'gmx mdrun, (VERSION|version)')
         self._metainfo_env = m_env
         self.log_parser = GromacsLogParser()
         self.traj_parser = MDAnalysisParser()
@@ -412,27 +412,26 @@ class GromacsParser(FairdiParser):
             sec_scc.single_configuration_calculation_to_system_ref = sec_run.section_system[n]
             sec_scc.single_configuration_to_calculation_method_ref = sec_run.section_method[-1]
 
-        # try to get it from log file
-        steps = self.log_parser.get('step', [])
-        if self.log_parser.get('averages') is not None:
-            steps.append(self.log_parser.get('averages'))
-        thermo_data = dict()
-        for step in steps:
-            if step.energies is None:
-                continue
-            keys = step.energies.keys()
-            for key in keys:
-                thermo_data.setdefault(key, [])
-                thermo_data[key].append(step.energies.get(key))
-            info = step.get('step_info', {})
-            thermo_data.setdefault('Time', [])
-            thermo_data['Time'].append(info.get('Time', None))
-        n_evaluations = len(steps)
-
-        if not thermo_data:
-            # get it from edr file
+        # get it from edr file
+        if len(self.energy_parser.keys()) > 0:
             thermo_data = self.energy_parser
             n_evaluations = self.energy_parser.length
+        else:
+            # try to get it from log file
+            steps = self.log_parser.get('step', [])
+            thermo_data = dict()
+            for n, step in enumerate(steps):
+                n = int(step.get('step_info', {}).get('Step', n))
+                if step.energies is None:
+                    continue
+                keys = step.energies.keys()
+                for key in keys:
+                    thermo_data.setdefault(key, [None] * len(forces))
+                    thermo_data[key][n] = step.energies.get(key)
+                info = step.get('step_info', {})
+                thermo_data.setdefault('Time', [None] * len(forces))
+                thermo_data['Time'][n] = info.get('Time', None)
+            n_evaluations = n + 1
 
         create_scc = False
         if len(forces) != n_evaluations:
@@ -506,10 +505,10 @@ class GromacsParser(FairdiParser):
         pbc = self.log_parser.get_pbc()
         for n in range(n_frames):
             positions = self.traj_parser.get_positions(n)
+            sec_system = sec_run.m_create(System)
             if positions is None:
                 continue
 
-            sec_system = sec_run.m_create(System)
             sec_system.number_of_atoms = self.traj_parser.get_n_atoms(n)
             sec_system.configuration_periodic_dimensions = pbc
             sec_system.simulation_cell = self.traj_parser.get_cell(n)
