@@ -16,4 +16,4 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-from .TINKERParser import TINKERParserInterface as TinkerParser
\ No newline at end of file
+from .tinker_parser import TinkerParser
