@@ -24,13 +24,13 @@ from pydantic import BaseModel, Field, validator
 from datetime import datetime
 import enum
 
-from nomad import utils, datamodel, search, processing
+from nomad import utils, datamodel, search, processing, config
 from nomad.metainfo.elastic_extension import ElasticDocument
 from nomad.utils import strip, create_uuid
 from nomad.datamodel import Dataset as DatasetDefinitionCls
 from nomad.doi import DOI
 
-from .auth import get_required_user
+from .auth import create_user_dependency
 from .entries import _do_exaustive_search
 from ..utils import create_responses, parameter_dependency_from_model
 from ..models import (
@@ -72,7 +72,7 @@ _existing_name_response = status.HTTP_400_BAD_REQUEST, {
 _dataset_is_fixed_response = status.HTTP_400_BAD_REQUEST, {
     'model': HTTPExceptionModel,
     'description': strip('''
-        The dataset already as a DOI and cannot be changed anymore.
+        The dataset already has a DOI and cannot be changed anymore.
     ''')}
 
 
@@ -191,13 +191,16 @@ async def get_dataset(
     response_model_exclude_unset=True,
     response_model_exclude_none=True)
 async def post_datasets(
-        create: DatasetCreate, user: User = Depends(get_required_user)):
+        create: DatasetCreate, user: User = Depends(create_user_dependency(required=True))):
     '''
     Create a new dataset.
     '''
 
+    if config.services.readonly:
+        raise HTTPException(status_code=status.HTTP_403_FORBIDDEN, detail='This installation of NOMAD is readonly.')
+
     now = datetime.now()
-    dataset_type = create.dataset_type if create.dataset_type is not None else 'owned'
+    dataset_type = create.dataset_type if create.dataset_type is not None else DatasetType.owned
 
     # check if name already exists
     existing_dataset = DatasetDefinitionCls.m_def.a_mongo.objects(
@@ -217,22 +220,28 @@ async def post_datasets(
         dataset_type=dataset_type)
     dataset.a_mongo.create()
 
-    # add dataset to entries in mongo and elastic
-    # TODO this should be part of a new edit API
-    if create.entries is not None:
-        es_query = cast(Query, {'calc_id': Any_(any=create.entries)})
-        mongo_query = {'_id': {'$in': create.entries}}
-        empty = len(create.entries) == 0
-    elif create.query is not None:
-        es_query = create.query
-        entries = _do_exaustive_search(
-            owner=Owner.public, query=create.query, user=user,
-            include=['calc_id'])
-        entry_ids = [entry['calc_id'] for entry in entries]
-        mongo_query = {'_id': {'$in': entry_ids}}
-        empty = len(entry_ids) == 0
-    else:
+    if dataset_type != DatasetType.owned:
+        dataset.query = create.query
+        dataset.entrys = create.entries
         empty = True
+    else:
+        # add dataset to entries in mongo and elastic
+        # TODO this should be part of a new edit API
+        if create.entries is not None:
+            es_query = cast(Query, {'calc_id': Any_(any=create.entries)})
+        elif create.query is not None:
+            es_query = create.query
+        else:
+            es_query = None
+
+        if es_query is None:
+            empty = True
+        else:
+            entries = _do_exaustive_search(
+                owner=Owner.user, query=es_query, user=user, include=['calc_id'])
+            entry_ids = [entry['calc_id'] for entry in entries]
+            mongo_query = {'_id': {'$in': entry_ids}}
+            empty = len(entry_ids) == 0
 
     if not empty:
         processing.Calc._get_collection().update_many(
@@ -262,11 +271,14 @@ async def post_datasets(
     response_model_exclude_none=True)
 async def delete_dataset(
         dataset_id: str = Path(..., description='The unique dataset id of the dataset to delete.'),
-        user: User = Depends(get_required_user)):
+        user: User = Depends(create_user_dependency(required=True))):
     '''
     Delete an dataset.
     '''
 
+    if config.services.readonly:
+        raise HTTPException(status_code=status.HTTP_403_FORBIDDEN, detail='This installation of NOMAD is readonly.')
+
     dataset = DatasetDefinitionCls.m_def.a_mongo.objects(dataset_id=dataset_id).first()
     if dataset is None:
         raise HTTPException(
@@ -327,11 +339,14 @@ async def delete_dataset(
     response_model_exclude_none=True)
 async def assign_doi(
         dataset_id: str = Path(..., description='The unique dataset id of the dataset to delete.'),
-        user: User = Depends(get_required_user)):
+        user: User = Depends(create_user_dependency(required=True))):
     '''
     Assign a DOI to a dataset.
     '''
 
+    if config.services.readonly:
+        raise HTTPException(status_code=status.HTTP_403_FORBIDDEN, detail='This installation of NOMAD is readonly.')
+
     dataset = DatasetDefinitionCls.m_def.a_mongo.objects(dataset_id=dataset_id).first()
     if dataset is None:
         raise HTTPException(
