@@ -160,7 +160,8 @@ services = NomadConfig(
     upload_limit=10,
     force_raw_file_decoding=False,
     download_scan_size=500,
-    download_scan_timeout=u'30m'
+    download_scan_timeout=u'30m',
+    readonly=False
 )
 
 oasis = NomadConfig(
@@ -284,7 +285,7 @@ datacite = NomadConfig(
 )
 
 meta = NomadConfig(
-    version='0.10.4',
+    version='0.10.12',
     commit=gitinfo.commit,
     release='devel',
     deployment='standard',
@@ -295,7 +296,8 @@ meta = NomadConfig(
     homepage='https://nomad-lab.eu',
     source_url='https://gitlab.mpcdf.mpg.de/nomad-lab/nomad-FAIR',
     maintainer_email='markus.scheidgen@physik.hu-berlin.de',
-    deployment_id='nomad-lab.eu/prod/rae'
+    deployment_id='nomad-lab.eu/prod/rae',
+    beta=None
 )
 
 gitlab = NomadConfig(
@@ -316,6 +318,8 @@ process_reuse_parser = True
 metadata_file_name = 'nomad'
 metadata_file_extensions = ('json', 'yaml', 'yml')
 enable_lazy_import = True
+encyclopedia_enabled = True
+aitoolkit_enabled = False
 
 
 def normalize_loglevel(value, default_level=logging.INFO):
