@@ -47,6 +47,23 @@ class EncyclopediaNormalizer(Normalizer):
         calc_enums = Calculation.calculation_type.type
         calc_type = calc_enums.unavailable
 
+        # Primarily try to determine the calculation type from workflow
+        # information
+        try:
+            workflow = self.entry_archive.section_workflow
+            workflow_map = {
+                "molecular_dynamics": calc_enums.molecular_dynamics,
+                "geometry_optimization": calc_enums.geometry_optimization,
+                "phonon": calc_enums.phonon_calculation,
+            }
+            workflow_enum = workflow_map.get(workflow.workflow_type)
+            if workflow_enum is not None:
+                calc.calculation_type = workflow_enum
+                return workflow_enum
+        except Exception:
+            pass
+
+        # Fall back to old frame sequence data
         try:
             sccs = self.section_run.section_single_configuration_calculation
         except Exception:
