@@ -1,16 +1,20 @@
-# Copyright 2018 Markus Scheidgen
 #
-# Licensed under the Apache License, Version 2.0 (the 'License');
+# Copyright The NOMAD Authors.
+#
+# This file is part of NOMAD. See https://nomad-lab.eu for further info.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
 #
-#   http://www.apache.org/licenses/LICENSE-2.0
+#     http://www.apache.org/licenses/LICENSE-2.0
 #
 # Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an'AS IS' BASIS,
+# distributed under the License is distributed on an "AS IS" BASIS,
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+#
 
 from nomad.datamodel.encyclopedia import (
     Calculation,
@@ -45,12 +49,16 @@ class PropertiesNormalizer():
                 kind = band.band_structure_kind
                 if kind != "vibrational":
                     valid = True
+                    if not band.section_k_band_segment:
+                        valid = False
+                        break
                     for segment in band.section_k_band_segment:
                         energies = segment.band_energies
                         k_points = segment.band_k_points
                         labels = segment.band_segm_labels
                         if energies is None or k_points is None or labels is None:
                             valid = False
+                            break
                     if valid:
                         representative_band = band
                         break
