@@ -21,7 +21,70 @@ import numpy as np
 from nomad.normalizing.normalizer import Normalizer
 from nomad.datamodel import EntryArchive
 from nomad.datamodel.metainfo.public import Workflow, GeometryOptimization, Phonon, Elastic,\
-    MolecularDynamics
+    MolecularDynamics, SinglePoint
+
+
+def resolve_difference(values):
+    delta_values = None
+
+    values = [v for v in values if v is not None]
+    for n in range(-1, -len(values), -1):
+        delta_values = abs(values[n] - values[n - 1])
+        if delta_values != 0.0:
+            break
+
+    return delta_values
+
+
+class SinglePointNormalizer(Normalizer):
+    def __init__(self, entry_archive):
+        super().__init__(entry_archive)
+
+    def normalize(self):
+        self.section = self.entry_archive.section_workflow.section_single_point
+        if not self.section:
+            self.section = self.entry_archive.section_workflow.m_create(SinglePoint)
+
+        if not self.section.single_point_calculation_method:
+            try:
+                method = self.section_run.section_method[-1]
+                self.section.single_point_calculation_method = method.electronic_structure_method
+            except Exception:
+                pass
+
+        scc = self.section_run.section_single_configuration_calculation
+        if not scc:
+            return
+
+        if not self.section.number_of_scf_steps:
+            self.section.number_of_scf_steps = len(scc[-1].section_scf_iteration)
+
+        energies = [scf.energy_total_scf_iteration for scf in scc[-1].section_scf_iteration]
+        delta_energy = resolve_difference(energies)
+        if not self.section.final_scf_energy_difference and delta_energy is not None:
+            self.section.final_scf_energy_difference = delta_energy
+
+        if not self.section.is_converged and delta_energy is not None:
+            try:
+                threshold = self.section_run.section_method[-1].scf_threshold_energy_change
+                self.section.is_converged = bool(delta_energy <= threshold)
+            except Exception:
+                pass
+
+        if not self.section.with_density_of_states:
+            self.section.with_density_of_states = len(scc[-1].section_dos) > 0
+
+        if not self.section.with_bandstructure:
+            self.section.with_bandstructure = len(scc[-1].section_k_band) > 0
+
+        if not self.section.with_eigenvalues:
+            self.section.with_eigenvalues = len(scc[-1].section_eigenvalues) > 0
+
+        if not self.section.with_volumetric_data:
+            self.section.with_volumetric_data = len(scc[-1].section_volumetric_data) > 0
+
+        if not self.section.with_excited_states:
+            self.section.with_excited_states = len(scc[-1].section_excited_states) > 0
 
 
 class GeometryOptimizationNormalizer(Normalizer):
@@ -86,35 +149,39 @@ class GeometryOptimizationNormalizer(Normalizer):
             except Exception:
                 pass
 
-        scc = self.section_run.section_single_configuration_calculation
-        if not self.entry_archive.section_workflow.calculation_result_ref:
-            if scc:
-                self.entry_archive.section_workflow.calculation_result_ref = scc[-1]
-
-        if not self.entry_archive.section_workflow.calculations_ref:
-            if scc:
-                self.entry_archive.section_workflow.calculations_ref = scc
-
         if not self.section.optimization_steps:
+            scc = self.section_run.section_single_configuration_calculation
             self.section.optimization_steps = len(scc)
 
+        if not self.section.input_energy_difference_tolerance:
+            try:
+                tolerance = self.section_run.section_sampling_method[-1].geometry_optimization_energy_change
+                self.section.input_energy_difference_tolerance = tolerance
+            except Exception:
+                pass
+
+        if not self.section.input_force_maximum_tolerance:
+            try:
+                tolerance = self.section_run.section_sampling_method[-1].geometry_optimization_threshold_force
+                self.section.input_force_maximum_tolerance = tolerance
+            except Exception:
+                pass
+
+        if not self.section.input_displacement_maximum_tolerance:
+            try:
+                tolerance = self.section_run.section_sampling_method[-1].geometry_optimization_geometry_change
+                self.section.input_displacement_maximum_tolerance = tolerance
+            except Exception:
+                pass
+
         if not self.section.final_energy_difference:
             energies = []
             for scc in self.section_run.section_single_configuration_calculation:
-                if scc.energy_total_T0:
-                    energies.append(scc.energy_total_T0)
+                if scc.energy_total:
+                    energies.append(scc.energy_total)
 
-            delta_energy = None
-            if len(energies) > 1:
-                delta_energy = abs(energies[-1] - energies[-2])
-
-            if delta_energy == 0.0:
-                try:
-                    delta_energy = abs(energies[-1] - energies[-3])
-                except Exception:
-                    pass
-
-            if delta_energy:
+            delta_energy = resolve_difference(energies)
+            if delta_energy is not None:
                 self.section.final_energy_difference = delta_energy
 
         if not self.section.final_force_maximum:
@@ -127,6 +194,37 @@ class GeometryOptimizationNormalizer(Normalizer):
             if max_force is not None:
                 self.section.final_force_maximum = max_force
 
+        if not self.section.final_displacement_maximum:
+            try:
+                system = self.section_run.system
+                displacements = [np.max(np.abs(
+                    system[n].atom_positions - system[n - 1].atom_positions)) for n in range(1, len(system))]
+                self.section.final_displacement_maximum = resolve_difference(displacements)
+            except Exception:
+                pass
+
+        if not self.section.is_converged_geometry:
+            # we can have several criteria for convergence: energy, force, displacement
+            criteria = []
+            try:
+                criteria.append(self.section.final_energy_difference <= self.section.input_energy_difference_tolerance)
+            except Exception:
+                pass
+
+            try:
+                criteria.append(self.section.final_force_maximum <= self.section.input_force_maximum_tolerance)
+            except Exception:
+                pass
+
+            try:
+                criteria.append(self.section.final_displacement_maximum <= self.section.input_displacement_maximum_tolerance)
+            except Exception:
+                pass
+
+            # converged when either criterion is met
+            if criteria:
+                self.section.is_converged_geometry = True in criteria
+
 
 class PhononNormalizer(Normalizer):
     def __init__(self, entry_archive):
@@ -137,6 +235,8 @@ class PhononNormalizer(Normalizer):
         if not scc:
             return
         sec_band = scc[0].section_k_band
+        if not sec_band:
+            return
         result = 0
         for band_segment in sec_band[0].section_k_band_segment:
             freq = band_segment.band_energies
@@ -146,15 +246,6 @@ class PhononNormalizer(Normalizer):
     def normalize(self):
         self.section = self.entry_archive.section_workflow.section_phonon
 
-        scc = self.section_run.section_single_configuration_calculation
-        if not self.entry_archive.section_workflow.calculation_result_ref:
-            if scc:
-                self.entry_archive.section_workflow.calculation_result_ref = scc[-1]
-
-        if not self.entry_archive.section_workflow.calculations_ref:
-            if scc:
-                self.entry_archive.section_workflow.calculations_ref = scc
-
         if not self.section:
             self.section = self.entry_archive.section_workflow.m_create(Phonon)
 
@@ -235,15 +326,6 @@ class ElasticNormalizer(Normalizer):
     def normalize(self):
         self.section = self.entry_archive.section_workflow.section_elastic
 
-        scc = self.section_run.section_single_configuration_calculation
-        if not self.entry_archive.section_workflow.calculation_result_ref:
-            if scc:
-                self.entry_archive.section_workflow.calculation_result_ref = scc[-1]
-
-        if not self.entry_archive.section_workflow.calculations_ref:
-            if scc:
-                self.entry_archive.section_workflow.calculations_ref = scc
-
         if not self.section:
             self.section = self.entry_archive.section_workflow.m_create(Elastic)
 
@@ -275,15 +357,6 @@ class MolecularDynamicsNormalizer(Normalizer):
     def normalize(self):
         self.section = self.entry_archive.section_workflow.section_molecular_dynamics
 
-        scc = self.section_run.section_single_configuration_calculation
-        if not self.entry_archive.section_workflow.calculation_result_ref:
-            if scc:
-                self.entry_archive.section_workflow.calculation_result_ref = scc[-1]
-
-        if not self.entry_archive.section_workflow.calculations_ref:
-            if scc:
-                self.entry_archive.section_workflow.calculations_ref = scc
-
         if not self.section:
             self.section = self.entry_archive.section_workflow.m_create(MolecularDynamics)
 
@@ -296,8 +369,7 @@ class MolecularDynamicsNormalizer(Normalizer):
 
 class WorkflowNormalizer(Normalizer):
     '''
-    This normalizer performs all produces a section all data necessary for the Optimade API.
-    It assumes that the :class:`SystemNormalizer` was run before.
+    This normalizer produces information specific to a workflow.
     '''
     def __init__(self, entry_archive):
         super().__init__(entry_archive)
@@ -305,16 +377,20 @@ class WorkflowNormalizer(Normalizer):
         self._phonon_programs = ['phonopy']
 
     def _resolve_workflow_type_vasp(self):
-        try:
-            ibrion = self.section_run.section_method[0].x_vasp_incarOut_IBRION
-        except Exception:
-            ibrion = 1
+        sec_method = self.section_run.section_method
+        if not sec_method:
+            return
 
-        if ibrion == 0:
-            workflow_type = "molecular_dynamics"
+        incar = self.section_run.section_method[0].x_vasp_incar_out
+        nsw = incar.get('NSW')
+        ibrion = -1 if nsw == 0 else incar.get('IBRION', 0)
+
+        if ibrion == -1:
+            return 'single_point'
+        elif ibrion == 0:
+            return 'molecular_dynamics'
         else:
-            workflow_type = "geometry_optimization"
-        return workflow_type
+            return 'geometry_optimization'
 
     def _resolve_workflow_type(self):
         # first get it from section_sampling_method
@@ -344,6 +420,11 @@ class WorkflowNormalizer(Normalizer):
             elif program_name == 'phonopy':
                 workflow_type = 'phonon'
 
+        # resolve if from scc
+        if not workflow_type:
+            if len(self.section_run.section_single_configuration_calculation) == 1:
+                workflow_type = 'single_point'
+
         return workflow_type
 
     def normalize(self, logger=None) -> None:
@@ -383,6 +464,18 @@ class WorkflowNormalizer(Normalizer):
         elif workflow.workflow_type == 'molecular_dynamics':
             MolecularDynamicsNormalizer(self.entry_archive).normalize()
 
+        elif workflow.workflow_type == 'single_point':
+            SinglePointNormalizer(self.entry_archive).normalize()
+
+        scc = self.section_run.section_single_configuration_calculation
+        if not self.entry_archive.section_workflow.calculation_result_ref:
+            if scc:
+                self.entry_archive.section_workflow.calculation_result_ref = scc[-1]
+
+        if not self.entry_archive.section_workflow.calculations_ref:
+            if scc:
+                self.entry_archive.section_workflow.calculations_ref = scc
+
         # remove the section workflow again, if the parser/normalizer could not produce a result
         if workflow.calculation_result_ref is None:
             self.entry_archive.m_remove_sub_section(EntryArchive.section_workflow, -1)
